@@ -123,16 +123,18 @@ class MediaObj: public Object
 class FramedObj: public SO<FramedObj, MediaObj>
 {
     public:
+        bool  hlBorder; // highlight border
 
-                      FramedObj(const char* thm_name, Rect plc);
+                      FramedObj(const FrameTheme& ft, Rect plc);
 
-         std::string& Theme() { return thmName; }
+          FrameTheme& Theme() { return thmName; }
+         std::string& ThemeName() { return thmName.themeName; }
           PosterLink& PosterItem() { return pstrLink; }
 
                 //void  Load(const char* thm_name, Rect& plc);
 
     protected:
-              std::string  thmName;
+               FrameTheme  thmName;
                PosterLink  pstrLink;
 };
 
@@ -147,28 +149,6 @@ class CanvasObj: public SO<CanvasObj, MediaObj>
 
 };
 
-// группа объектов
-class ListObj: public Object
-{
-    public:
-        typedef std::vector<Object*>  ArrType;
-        typedef    ArrType::iterator  Itr;
-
-               ~ListObj() { Clear(); }
-
-          void  Clear();
-          void  Clear(Object* obj);
-
-          void  Ins(Object& obj) { objArr.push_back(&obj); }
-       ArrType& List() { return objArr; }
-
- virtual  void  Accept(ObjVisitor& vis);
-
-    protected:
-
-        ArrType objArr; // храним объекты тут
-};
-
 } // namespace Composition
 
 #endif // #ifndef __MBASE_COMPOSITE_COMPONENT_H__
