@@ -118,9 +118,25 @@ static void SerializeColor(Archieve& ar, const char* tag_name, RGBA::Pixel& clr)
 void MenuMD::SerializeImpl(Archieve& ar)
 {
     // * параметры
-    ar( "Params",     mPrms   )
-      ( "Color",      color   );
-    SerializeReference(ar, "BGRef", bgRef);
+    ar( "Params",     mPrms   );
+
+    // * фон
+    if( CanSrl(ar, 1) )
+    {
+        ArchieveStackFrame asf(ar, "Background");
+        ar("SpanType", bgSet.bsTyp);
+        SerializeColor(ar, "Color", bgSet.sldClr);
+        SerializeReference(ar, "BGRef", bgRef);
+    }
+    else
+    {
+        // загрузка версий 1.0.x
+        bgSet.bsTyp = bstSTRETCH; // исторически
+        //ar( "Color",      color   );
+        SerializeColor(ar, "Color", bgSet.sldClr);
+        SerializeReference(ar, "BGRef", bgRef);
+    }
+
     ar( "MotionData", mtnData );
 
     // * цвета субкартинок
@@ -305,8 +321,21 @@ void MenuItemMD::SerializeImpl(Archieve& ar)
 
 void FrameItemMD::SerializeImpl(Archieve& ar)
 {
-    ar & NameValue("Frame", themeStr);
+    if( CanSrl(ar, 1) )
+    {
+        ArchieveStackFrame asf(ar, "FrameTheme");
+        ar("Name",   theme.themeName)
+          ("IsIcon", theme.isIcon   );
+    }
+    else
+    {
+        // загрузка версий < 1
+        ar("Frame", theme.themeName);
+        theme.isIcon = false;
+    }
     SerializeReference(ar, "Poster", posterRef);
+    if( CanSrl(ar, 2) )
+        ar("HighlightBorder", hlBorder);
 
     MyParent::SerializeImpl(ar);
 }
@@ -326,9 +355,14 @@ Menu MakeMenu(const std::string& name)
     return menu;
 }
 
+std::string MenuAutoName(int old_sz)
+{
+    return MakeAutoName(_("Menu"), old_sz);
+}
+
 Menu MakeMenu(int old_sz)
 {
-    return MakeMenu(MakeAutoName(_("Menu"), old_sz));
+    return MakeMenu(MenuAutoName(old_sz));
 }
 
 } // namespace Project
