@@ -71,6 +71,21 @@ struct SubpicturePalette
     SubpicturePalette();
 };
 
+enum BackSpanType
+{
+    bstPAN_SCAN = 0,  // (по умолчанию)
+    bstLETTERBOX,     //
+    bstSTRETCH,       // растянуть, не считаясь с пропорциями
+};
+
+struct BackSettings
+{
+    BackSpanType  bsTyp;
+     RGBA::Pixel  sldClr; // "select"
+     
+     BackSettings(): bsTyp(bstPAN_SCAN) {}
+};
+
 // меню
 class MenuMD: public PSO<MenuMD, Media> // от Media
 {
@@ -79,16 +94,16 @@ class MenuMD: public PSO<MenuMD, Media> // от Media
         typedef std::vector<MenuItem> ListType;
         typedef   ListType::iterator  Itr;
 
+        BackSettings  bgSet;
+   SubpicturePalette  subPal;
+        
                            MenuMD();
 
                MenuParams& Params() { return mPrms; }
                  ListType& List()   { return itmLst; }
                 MediaItem& BgRef()  { return bgRef; }
-              std::string& Color()  { return color; }
                MotionData& MtnData(){ return mtnData; }
 
-        SubpicturePalette  subPal;
-
     virtual   std::string  TypeString() { return "Menu"; }
     virtual          void  SerializeImpl(Archieve& /*ar*/);
 
@@ -96,7 +111,6 @@ class MenuMD: public PSO<MenuMD, Media> // от Media
             MenuParams  mPrms;
               ListType  itmLst; // список глав
              MediaItem  bgRef;  // фон меню
-           std::string  color;
             MotionData  mtnData;
 };
 
@@ -133,18 +147,19 @@ class FrameItemMD: public PSO<FrameItemMD, MenuItemMD>// от MenuItemMD
 {
     typedef MenuItemMD MyParent;
     public:
+                     bool  hlBorder; // highlight border
 
-                           FrameItemMD(MenuMD* own)
+                           FrameItemMD(MenuMD* own): hlBorder(false)
                            { SetOwner(own); }
 
       virtual std::string  TypeString() { return "Frame Item"; }
        virtual       void  SerializeImpl(Archieve& ar);
 
-              std::string& Theme() { return themeStr; }
+               FrameTheme& Theme() { return theme; }
                 MediaItem& Poster() { return posterRef; }
        
     protected:
-              std::string  themeStr;
+               FrameTheme  theme;
                 MediaItem  posterRef;
 };
 
