@@ -2,7 +2,7 @@
 // mdemux/mpeg_video.cpp
 // This file is part of Bombono DVD project.
 //
-// Copyright (c) 2007-2009 Ilya Murav'jov
+// Copyright (c) 2007-2010 Ilya Murav'jov
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -385,8 +385,8 @@ void HeaderDecode::NextState(Decoder& dcr)
         InvalidState(dcr);
         return;
     }
-    dat.vbvBufSz  = (hdr.inf[3] && 0x1f) << 5;
-    dat.vbvBufSz |=  hdr.inf[4]          >> 3;
+    dat.vbvBufSz  = (hdr.inf[3] & 0x1f) << 5;
+    dat.vbvBufSz |=  hdr.inf[4]         >> 3;
 
     // 2 матрицы
     if( hdr.inf[4] & 2 ) //  intra quantiser matrix
