@@ -2,7 +2,7 @@
 // mdemux/videoline.cpp
 // This file is part of Bombono DVD project.
 //
-// Copyright (c) 2007-2009 Ilya Murav'jov
+// Copyright (c) 2007-2010 Ilya Murav'jov
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -230,6 +230,32 @@ void FrameList::Init()
     flStt = &RawFL::Instance();
 }
 
+void FrameList::Setup( SequenceData& seq )
+{
+    // смена последовательности - плохой признак
+    if( IsInit() )
+    {
+        // DVBcut_seq_change.mpg - смена с прогрессивной на чересстрочную (DVBcut разрешает
+        // соединять подобное без перекодирования, что само по себе нехорошо);
+        // TMPG Author принял молча, без возражений => выдаем только предупреждение
+
+        // :TODO: размеры, sar и частота кадров - слишком чувствительны для смены =>
+        // (запрещать в VideoLine::TagData(), собственно пред. prevSeq хранить в Decoder)
+        LOG_WRN << "Sequence change: (wdh, hgt) = " << Point(seq.wdh, seq.hgt) 
+            << "; sample aspect ratio = " << seq.sarCode 
+            << "; frame rate = " << seq.framRat 
+            << "; vbvBufSz = " << seq.vbvBufSz 
+            << "; profile = " << seq.plId
+            << "; is progressive = " << seq.isProgr
+            << "; chroma format = " << seq.chromaFrmt
+            << "; lowDelay = " << seq.lowDelay
+            << io::endl;
+    }
+
+    if( seq.IsInit() )
+        timeShift = seq.framRat.y/(double)seq.framRat.x;
+}
+
 void FrameList::Bind(Itr* it)
 {
     it->itrPos = iterLst.insert(iterLst.end(), it);
@@ -619,7 +645,7 @@ void VideoLine::GetData(Mpeg::Demuxer& dmx, int len)
 {
     double pts = dmx.CurPTS();
     double scr = dmx.CurSCR();
-    ASSERT( IsTSValid(scr) );
+    ASSERT_OR_UNUSED_VAR( IsTSValid(scr), scr );
 
     // пока не дошли до блока с pts не начинаем
     if( !IsTSValid(pts) )
@@ -812,6 +838,7 @@ void VideoLine::TagData(Decoder&, VideoTag tag)
         {
             framLst.Setup( prsCont.dcr.seqInf );
 
+#ifdef CONFIG_GPL
             io::stream& strm = prsCont.dmx.ObjStrm();
             MpegDecodec& m2d = prsCont.m2d;
 
@@ -822,6 +849,7 @@ void VideoLine::TagData(Decoder&, VideoTag tag)
                  (it != end) && !m2d.IsInit(); ++it )
                 m2d.ReadForInit(*it, strm);
             ASSERT( m2d.IsInit() );
+#endif // CONFIG_GPL
         }
         break;
     case vtERROR:
