@@ -257,8 +257,10 @@ void SPRenderVis::Visit(TextObj& t_obj)
         Make(t_obj).Render();
         // все равно приходится явно дискретизировать, потому что подчеркивание, например,
         // добавляет еще несколько цветов (особенно если есть пересечение его с буквой)
-        Rect plc = CalcRelPlacement(t_obj.Placement());
-        DiscreteByAlpha(MakeSubPixbuf(drw->Canvas(), plc), clr);
+        RefPtr<Gdk::Pixbuf> canv_pix = drw->Canvas();
+        // :TRICKY: раз уж напрямую правим, то явно соблюдаем ограничения
+        Rect plc = Intersection(CalcRelPlacement(t_obj.Placement()), PixbufBounds(canv_pix));
+        DiscreteByAlpha(MakeSubPixbuf(canv_pix, plc), clr);
 
         ScriptButton(spuNode, isSelect, plc, cnvBuf);
     }
@@ -617,7 +619,7 @@ AutoSrcData::AutoSrcData(bool is4_3_): videoOK(false),
     dar(DVDAspect(is4_3_)), audioNum(1) {}
 
 AutoDVDTransData::AutoDVDTransData(bool is4_3_): is4_3(is4_3_), 
-    asd(is4_3_), threadsCnt(1) {}
+    asd(is4_3_), threadsCnt(1), pass(0) {}
 
 static int PadSize(int free_space)
 {
@@ -648,24 +650,38 @@ static std::string FFImgSizeOption(const Point& sz, int val, bool is_left_right)
     return FFSizeOption(img_sz);
 }
 
-static std::string FFPadFilterSet(const Point& sz, int val, bool is_left_right)
-{
-    int x = 0, y = 0;
-    if( is_left_right )
-        x = val;
-    else
-        y = val;
-
-    return boost::format("%1% -vf pad=%2%:%3%:%4%:%5%:black") 
-        % FFImgSizeOption(sz, val, is_left_right) % sz.x % sz.y % x % y % bf::stop;
-}
-
 static std::string FFSizeSet(const Point& sz, int val, 
-                                  bool is_left_right, bool is_vf)
+                             bool is_left_right, const FFmpegVersion& ff_ver)
 {
     std::string sz_str;
-    if( is_vf )
-        sz_str = FFPadFilterSet(sz, val, is_left_right);
+    // вместо -padX использовать -vf pad=w:h:x:y:black
+    if( IsVersionGE(ff_ver.avfilter, TripleVersion(1, 20, 0)) )
+    {
+        int x = 0, y = 0;
+        if( is_left_right )
+            x = val;
+        else
+            y = val;
+
+        std::string pad_filter = boost::format("pad=%1%:%2%:%3%:%4%:black") % sz.x % sz.y % x % y % bf::stop;
+        if( IsVersionGE(ff_ver.avfilter, TripleVersion(2, 20, 1)) )
+        {
+            // теперь фильтр скалирования, -s wxh, поставлен в конец цепочки, и вроде
+            // как нет способа это изменить; поэтому:
+            // - нужно предварительное скалирование (-vf scale=wxh)
+            // - а вот -s full_w x full_h тоже нужен, потому что иначе сработает -s из
+            //   опции -target 
+            // - хорошо хоть конечное скалирование тривиально (и afilter это понимает),
+            //   так как размер картинки после pad равен -s
+            sz_str = boost::format("%1% -vf scale=%2%:%3%,%4%") 
+                % FFSizeOption(sz) % (sz.x-2*x) % (sz.y-2*y) % pad_filter % bf::stop;
+        }
+        else
+        {
+            sz_str = boost::format("%1% -vf %2%") 
+                % FFImgSizeOption(sz, val, is_left_right) % pad_filter % bf::stop;
+        }
+    }
     else
     {
         const char* fmt = is_left_right ? "%1% -padleft %2% -padright %2%" : "%1% -padtop %2% -padbottom %2%" ;
@@ -686,11 +702,36 @@ std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData
     // * предполагается после создания команды ее вызов => требуется
     // проверка такой возможности
     FFmpegVersion ff_ver = CheckFFDVDEncoding();
-    // вместо -padX использовать -vf pad=w:h:x:y:black
-    bool is_vf = IsVersionGE(ff_ver.avfilter, TripleVersion(1, 20, 0));
-
     // *
-    const char* target =  is_pal ? "pal" : "ntsc" ;
+    std::string target = boost::format("-target %1%-dvd") % (is_pal ? "pal" : "ntsc") % bf::stop ;
+    if( IsVersionGE(ff_ver.avformat, TripleVersion(54, 20, 1)) )
+    {
+        // :KLUDGE: новый парсер параметров от Anton Khirnov сломал установка всех opt_default(),
+        // вызванных ненапрямую (например -target), поэтому вручную (пока)
+        
+        // Применение опций (:TODO: диагноз => добавить как ошибку в libav):
+        //split_commandline() = opt_default(): av_dict_set(&codec_opts, opt, arg)
+        //finish_group(): g->codec_opts  = codec_opts;
+        //# как исправить: в open_files(), между parse_optgroup() и open_file() скопировать опции в OptionsContext.g->codec_opts,
+        //# а также возможно и в ->format_opts и ->opts
+        //new_output_stream(): ost->opts = filter_codec_opts(OptionsContext.g->codec_opts)
+        //transcode_init():    avcodec_open2(ost->st->codec, codec, &ost->opts) => AVCodecContext.rc_max_rate
+        
+        //opt_default(NULL, "g", norm == PAL ? "15" : "18");
+        //
+        //opt_default(NULL, "b", "6000000");
+        //opt_default(NULL, "maxrate", "9000000");
+        //opt_default(NULL, "minrate", "0"); // 1500000;
+        //opt_default(NULL, "bufsize", "1835008"); // 224*1024*8;
+        //
+        //opt_default(NULL, "packetsize", "2048");  // from www.mpucoder.com: DVD sectors contain 2048 bytes of data, this is also the size of one pack.
+        //opt_default(NULL, "muxrate", "10080000"); // from mplex project: data_rate = 1260000. mux_rate = data_rate * 8
+        //
+        //opt_default(NULL, "b:a", "448000");
+        target = boost::format("%1% -g %2% -b 6000000 -maxrate 9000000 -minrate 0 -bufsize 1835008 -packetsize 2048 -muxrate 10080000 -b:a 448000")
+            % target % (is_pal ? "15" : "18") % bf::stop;
+    }
+    
     Point DVDDimension(DVDDims dd, bool is_pal);
     Point sz = DVDDimension(td.dd, is_pal);
 
@@ -713,14 +754,14 @@ std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData
         // справа и слева
         int val = PadSize(sz.x - img_sz.x);
         if( val )
-            sz_str = FFSizeSet(sz, val, true, is_vf);
+            sz_str = FFSizeSet(sz, val, true, ff_ver);
     }
     else if( img_sz.y < sz.y )
     {
         // сверху и снизу
         int val = PadSize(sz.y - img_sz.y);
         if( val )
-            sz_str = FFSizeSet(sz, val, false, is_vf);
+            sz_str = FFSizeSet(sz, val, false, ff_ver);
     }
 
     // * доп. опции
@@ -751,9 +792,35 @@ std::string FFmpegToDVDArgs(const std::string& out_fname, const AutoDVDTransData
             add_audio_str += " -acodec ac3 -newaudio";
     }
     
-    return boost::format("-target %1%-dvd -aspect %2% %3% %4% -y %7% %5%%6%")
+    std::string full_out_path = out_fname;
+    // * двухпроходное кодирование
+    int pass = atd.pass;
+    if( pass )
+    {
+        AppendOpts(add_opts, boost::format("-pass %1% -passlogfile %2%") % pass % FilenameForCmd(full_out_path + ".vlog") % bf::stop);
+        if( pass == 1 )
+        {
+            // :TRICKY: на первом шаге важна только статистика, но
+            // ffmpeg предлагает отрубить только запись в выходной файл и не писать аудио
+#ifdef _WIN32
+            full_out_path = "NUL";
+#else
+            full_out_path = "/dev/null";
+#endif
+            // :TRICKY: с -an второй проход может быть неидентичен первому,
+            // что выдает ошибку на Chinese_1080p-mpeg2.ts, ffmpeg 1.1.3:
+            // Input is longer than 2-pass log file
+            // Video encoding failed
+            // :TODO: пока убрал эту опцию для более надежной работы, но
+            // вообще-то надо разрешить проблему и определиться (да/нет, 
+            // вопрос только в чуть более быстрой скорости)
+            //AppendOpts(add_opts, "-an");
+        }
+    }
+    
+    return boost::format("%1% -aspect %2% %3% %4% -y %7% %5%%6%")
         % target % (is_4_3 ? "4:3" : "16:9") % sz_str
-        % bitrate_str % FilenameForCmd(out_fname) % add_audio_str % add_opts % bf::stop;
+        % bitrate_str % FilenameForCmd(full_out_path) % add_audio_str % add_opts % bf::stop;
 }
 
 std::string FFmpegToDVDArgs(const std::string& out_fname, bool is_4_3, bool is_pal)
@@ -818,6 +885,9 @@ std::string FFmpegPostArgs(const std::string& out_fname, bool is_4_3, bool is_pa
             shift = boost::format("-ss %.2f ") % aai.shift % bf::stop;
         a_input = boost::format("%2%-i %1% %3%") % a_fname % shift % map % bf::stop; 
     }
+    // начиная с libav 0.8 ставить -t нужно прямо перед опциями выходного файла => после всех -i
+    if( aai.durtn )
+        a_input = boost::format("%1% -t %2$.2f") % a_input % aai.durtn % bf::stop;
 
     return a_input + " " + FFmpegToDVDArgs(out_fname, is_4_3, is_pal);
 }
@@ -1016,10 +1086,8 @@ void RunFFmpegCmd(const std::string& cmd, const ReadReadyFnr& add_fnr)
     RunExtCmd(cmd, AVCnvBin(), add_fnr);
 }
 
-static FFmpegVersion CalcFFmpegVersion();
-
 // кодируем из Menu.png => Menu.mpg
-static void EncodeStillMenu(const std::string& mn_dir, double durtn, const AudioArgInput& aai)
+static void EncodeStillMenu(const std::string& mn_dir, const AudioArgInput& aai)
 {
     std::string img_fname = AppendPath(mn_dir, "Menu.png");
 
@@ -1029,8 +1097,8 @@ static void EncodeStillMenu(const std::string& mn_dir, double durtn, const Audio
     // git log -p  -- libavformat/version.h | grep LIBAVFORMAT_VERSION_MINOR | less
     const char* loop_opt = IsVersionGE(CalcFFmpegVersion().avformat, TripleVersion(53, 6, 0)) ? "-loop 1" : "-loop_input" ;
     //std::string ffmpeg_cmd = boost::format("%4% -t %3$.2f -loop_input -i \"%1%\" %2%")
-    std::string ffmpeg_cmd = boost::format("%4% %5% -i \"%1%\" -t %3$.2f %2%") 
-        % img_fname % MakeFFmpegPostArgs(mn_dir, aai) % durtn % AVCnvBin() % loop_opt % bf::stop;
+    std::string ffmpeg_cmd = boost::format("%3% %4% -i \"%1%\" %2%") 
+        % img_fname % MakeFFmpegPostArgs(mn_dir, aai) % AVCnvBin() % loop_opt % bf::stop;
 
     RunFFmpegCmd(ffmpeg_cmd);
 }
@@ -1038,7 +1106,10 @@ static void EncodeStillMenu(const std::string& mn_dir, double durtn, const Audio
 static void SaveStillMenuMpg(const std::string& mn_dir, Menu mn)
 {
     SaveMenuPng(mn_dir, mn);
-    EncodeStillMenu(mn_dir, MenuDuration(mn), MotionMenuAAI(mn));
+    AudioArgInput aai = MotionMenuAAI(mn);
+    aai.durtn = MenuDuration(mn);
+    
+    EncodeStillMenu(mn_dir, aai);
 }
 
 FFmpegCloser::~FFmpegCloser()
@@ -1153,12 +1224,16 @@ void TestFFmpegForDVDEncoding(const std::string& conts)
     static re::pattern dvd_format("^ .E dvd"RG_EW);
     CheckStrippedFFmpeg(dvd_format, conts, "dvd format");
 
-    static re::pattern mpeg2video_codec("^ .EV... mpeg2video"RG_EW);
+// :TRICKY: с версии libavcodec 54 при выводе начальный пробел не ставят => поэтому ?
+// ("спасибо" Anton Khirnov за очередное "улучшение") 
+#define _CPP_ "^ ?"
+    static re::pattern mpeg2video_codec(_CPP_".EV... mpeg2video"RG_EW);
     CheckStrippedFFmpeg(mpeg2video_codec, conts, "mpeg2 video encoder");
 
     // по факту ffmpeg всегда использует ac3, однако mp2 тоже возможен
-    static re::pattern ac3_codec("^ .EA... ac3"RG_EW);
+    static re::pattern ac3_codec(_CPP_".EA... ac3"RG_EW);
     CheckStrippedFFmpeg(ac3_codec, conts, "ac3 audio encoder");
+#undef _CPP_
 }
 
 TripleVersion FindAVVersion(const std::string& conts, const char* avlib_name)
@@ -1177,7 +1252,7 @@ TripleVersion FindAVFilterVersion(const std::string& conts)
     return FindAVVersion(conts, "libavfilter");
 }
 
-static FFmpegVersion CalcFFmpegVersion()
+FFmpegVersion CalcFFmpegVersion()
 {
     // *
     std::string conts;
@@ -1313,10 +1388,18 @@ bool RenderMainPicture(const std::string& out_dir, Menu mn, int i)
     else
     {
         SaveMenuPng(mn_dir, mn);
-        // :TRICKY: значение 0.1 секунда - эмпирическое (в скрипте ADVD.py ставить
+        // :TRICKY: значение 0.2 секунда - эмпирическое (в скрипте ADVD.py ставить
         // равное значение); по опыту c mpeg2enc кодировать нужно > одного кадра,
         // чтобы было качество; вероятно подобное применимо и к ffmpeg
-        EncodeStillMenu(mn_dir, 0.1, AudioArgInput());
+        // :TODO: заметил, что значение q для первого кадра всегда слишком большое
+        // (порядка 5), а затем быстро выправляется; из-за этого первый кадр плохого
+        // качества, а потому нужно, чтобы кол-во кадров в меню было больше одного;
+        // в реальности плейеры могут показывают не последний кадр (а хрен знает какой),
+        // поэтому и 3 кадров мадо (0.1 секунда) => увеличил до 0.2
+        // а лучше надо разобраться, почему в первый раз q (ff_rate_estimate_qscale(s))
+        // сильно отличается от второго раза, и почему так происходит
+        double dur = 0.2;
+        EncodeStillMenu(mn_dir, AudioArgInput(dur));
     }
 
     if( IsMenuToBe4_3() )
