@@ -370,7 +370,7 @@ static std::string SrcFilename(VideoItem vi)
 static std::string PrefixCnvPath(VideoItem vi, const std::string& out_dir)
 {
     std::string dst_fname = boost::format("%1%.%2%") % GetAuthorNumber(vi) 
-        % fs::path(SrcFilename(vi)).leaf() % bf::stop;
+        % fs::name_str(SrcFilename(vi)) % bf::stop;
     return AppendPath(out_dir, dst_fname);
 }
 
@@ -689,14 +689,7 @@ std::string FFmpegToDVDTranscode(const std::string& src_fname, const std::string
         % FFmpegToDVDArgs(dst_fname, atd, is_pal, td) % AVCnvBin() % bf::stop;
 }
 
-// ffmpeg выводит статистику первого создаваемого файла каждые полсекунды,
-// см. print_report() (при verbose=1, по умолчанию)
-// Формат размера: "size=%8.0fkB"
-re::pattern FFmpegSizePat( "size= *"RG_NUM"kB"); 
-// Формат длительности: "time=%0.2f"
-re::pattern FFmpegDurPat( "time="RG_FLT);
-
-typedef boost::function<double(double)> PercentFunctor;
+typedef boost::function<void(double)> PercentFunctor;
 
 struct Job
 {
@@ -721,16 +714,20 @@ struct JobData
         JobList  jLst;
             int  todoIdx;
     
+                 // :KLUDGE: проброс для UpdateJobs() и CalcTransPercent() - 
+                 // можно как замыкание оформить (атрибут на JobData вместо UpdateJobs())
         io::pos  transDone;
         io::pos  transTotal;
     std::string  outDir;
+            int  pass;
+            
        ExitData  lastED;
     std::string  exception; // проброс исключений из gtk_main()
-           
-    JobData(): todoIdx(0), transDone(0), transTotal(0) {}
+            
+    JobData(): todoIdx(0), transDone(0), transTotal(0), pass(0) {}
 };
 
-static double CalcTransPercent(double cur_dur, Job& job, JobData& jd, double full_dur)
+static void CalcTransPercent(double cur_dur, Job& job, JobData& jd, double full_dur)
 {
     //return (std::min(sz * 1024, trans_val) + trans_done)/double(trans_total);
     //return (std::min(cur_dur/full_dur, 1.) * trans_val + trans_done)/double(trans_total);
@@ -738,9 +735,30 @@ static double CalcTransPercent(double cur_dur, Job& job, JobData& jd, double ful
     double res = 0.;
     boost_foreach( Job& j, jd.jLst )
         res += j.transDone;
-    return (res + jd.transDone)/double(jd.transTotal);
+    double per = (res + jd.transDone)/double(jd.transTotal);
+    
+    int pass = jd.pass;
+    if( pass )
+    {
+        // :TRICKY: первый проход делается чуть быстрее из-за
+        // отсутствия реальной записи и отсутствия кодирования звука,
+        // но это все равно мало - делим 50/50
+        if( pass == 1 )
+            per /= 2;
+        else
+            // pass == 2
+            per = (1 + per) / 2;
+    }
+    Author::SetStageProgress(per);
 }
 
+// ffmpeg выводит статистику первого создаваемого файла каждые полсекунды,
+// см. print_report() (при verbose=1, по умолчанию)
+// Формат размера: "size=%8.0fkB"
+re::pattern FFmpegSizePat( "size= *"RG_NUM"kB"); 
+// Формат длительности: "time=%0.2f"
+re::pattern FFmpegDurPat( "time="RG_FLT);
+
 static void OnTranscodePrintParse(const char* dat, int sz, const PercentFunctor& fnr)
 {
     re::match_results what;
@@ -763,9 +781,25 @@ static void OnTranscodePrintParse(const char* dat, int sz, const PercentFunctor&
     {
         double dur;
         if( ExtractDouble(dur, what) )
+            fnr(dur);
+    }
+}
+
+// Формат длительности для ffmpeg c коммита dd471070: "time=%02d:%02d:%02d.%02d"
+// Образец: frame=  208 fps= 58 q=2.0 size=     476kB time=00:00:08.44 bitrate= 461.9kbits/s dup=1 drop=0
+re::pattern FFmpegNewDurPat( "time="RG_NUM":"RG_NUM":"RG_FLT);
+
+static void OnTranscodeHMSParse(const char* dat, int sz, const PercentFunctor& fnr)
+{
+    re::match_results what;
+    if( re::search(std::string(dat, sz), what, FFmpegNewDurPat) )
+    {
+        int hours = AsInt(what, 1), mins = AsInt(what, 2);
+        double secs;
+        if( ExtractDouble(secs, what, 3) )
         {
-            double per = fnr(dur);
-            Author::SetStageProgress(per);
+            double dur = (hours * 60 + mins) * 60 + secs;
+            fnr(dur);
         }
     }
 }
@@ -846,6 +880,7 @@ static bool UpdateJobs(JobData& jd)
             atd.asd = rtc.asd;
             atd.asd.audioNum = OutAudioNum(atd.asd);
             atd.threadsCnt = coeff;
+            atd.pass = jd.pass;
 
             DVDTransData td = GetRealTransData(vi);
             td.ctmFFOpt = CustomFFOpts(vi);
@@ -855,7 +890,13 @@ static bool UpdateJobs(JobData& jd)
             Job& new_job = jl.back();
 
             PercentFunctor fnr = bb::bind(&CalcTransPercent, _1, b::ref(new_job), b::ref(jd), rtc.duration);
-            ReadReadyFnr rr_fnr = bb::bind(&OnTranscodePrintParse, _1, _2, fnr);
+            // так определяем avconv vs. ffmpeg в runtime
+            bool is_ffmpeg_bin = strcmp(AVCnvBin(), "ffmpeg") == 0;
+            ReadReadyFnr rr_fnr;
+            if( is_ffmpeg_bin && IsVersionGE(CalcFFmpegVersion().avformat, TripleVersion(53, 2, 1)) )
+                rr_fnr = bb::bind(&OnTranscodeHMSParse, _1, _2, fnr);
+            else
+                rr_fnr = bb::bind(&OnTranscodePrintParse, _1, _2, fnr);
 
             int out_err[2];
             GPid pid = Spawn(0, ffmpeg_cmd.c_str(), out_err, true);
@@ -956,7 +997,15 @@ void RunSpumux(const std::string& xml_fname, const std::string& src_fname, const
 {
     CheckSpumuxFontFile();
     std::string spumux_cmd = boost::format("spumux -m dvd -s%4% %1% < %2% > %3%") 
-        % FilenameForCmd(xml_fname) % src_fname % dst_fname % stream_id % bf::stop;
+        % FilenameForCmd(xml_fname)
+#ifdef _WIN32
+	% src_fname % dst_fname 
+#else
+	// :KLUDGE: из-за неправильного решения с реализацией перенаправления
+	// приходится действовать #ifdef'ами
+        % FilenameForCmd(src_fname) % FilenameForCmd(dst_fname) 
+#endif      
+	% stream_id % bf::stop;
     RunExtCmd(spumux_cmd, "spumux", ReadReadyFnr(), dir);
 }
 
@@ -1010,6 +1059,27 @@ bool IsSConsAuthoring()
     return PrefToBool(PrefContents("script_authoring"));
 }
 
+static void TranscodeVideos(int pass, const std::string& out_dir)
+{
+    JobData jd;
+    jd.transTotal = ProjectStat().transSum;
+    jd.outDir     = out_dir;
+    jd.pass       = pass;
+    
+    if( UpdateJobs(jd) )
+    {
+        ActionFunctor& stop_fnr = Author::GetES().eDat.stopFnr;
+        stop_fnr = bb::bind(&StopJobPool, b::ref(jd));
+        Gtk::Main::run();
+        stop_fnr.clear();
+        
+        if( jd.exception.size() )
+            Author::Error(jd.exception);
+        Author::CheckAbortByUser();
+        Author::CheckAppED(jd.lastED, AVCnvBin());
+    }
+}
+
 static void AuthorImpl(const std::string& out_dir)
 {
     AuthorSectionInfo((str::stream() << "Build DVD-Video in folder: " << out_dir).str());
@@ -1019,6 +1089,7 @@ static void AuthorImpl(const std::string& out_dir)
     Author::ExecState& es = Author::GetES();
 
     // * транскодирование
+    Author::SetStage(Author::stTRANSCODE);
     //io::pos trans_done = 0, trans_total = ProjectStat().transSum;
     //boost_foreach( VideoItem vi, AllTransVideos() )
     //{
@@ -1045,25 +1116,14 @@ static void AuthorImpl(const std::string& out_dir)
     //
     //    trans_done += trans_val;
     //}
-    Author::SetStage(Author::stTRANSCODE);
+
+    if( Prefs().is2Pass )
     {
-        JobData jd;
-        jd.transTotal = ProjectStat().transSum;
-        jd.outDir     = out_dir;
-        
-        if( UpdateJobs(jd) )
-        {
-            ActionFunctor& stop_fnr = es.eDat.stopFnr;
-            stop_fnr = bb::bind(&StopJobPool, b::ref(jd));
-            Gtk::Main::run();
-            stop_fnr.clear();
-            
-            if( jd.exception.size() )
-                Author::Error(jd.exception);
-            Author::CheckAbortByUser();
-            Author::CheckAppED(jd.lastED, AVCnvBin());
-        }
+        TranscodeVideos(1, out_dir);
+        TranscodeVideos(2, out_dir);
     }
+    else
+        TranscodeVideos(0, out_dir);
 
     // * субтитры
     boost_foreach( VideoItem vi, AllVideos() )
