@@ -24,9 +24,6 @@
 
 #include <mgui/menu-rgn.h>
 
-#include <mlib/range/any_range.h>
-#include <mlib/foreach.h>
-
 //
 // Iterating over selected objects; example:
 //  boost_foreach( Comp::MediaObj* obj, SelectedMediaObjs(edt_area) )
@@ -35,7 +32,9 @@
 //      break;
 //  }
 //
-fe::range<Comp::MediaObj*> SelectedMediaObjs();
+typedef fe::range<Comp::MediaObj*> MediaObjRange;
+MediaObjRange SelectedMediaObjs();
+Rect ConvexHull(const MediaObjRange& lst);
 
 
 #endif // __MGUI_EDITOR_FE_SELECT_H__
