@@ -29,7 +29,7 @@
 #include <mgui/win_utils.h>
 #include <mgui/project/menu-render.h>
 #include <mgui/project/dnd.h>
-
+#include <mgui/sdk/widget.h> // SetColor()
 
 #include <mbase/resources.h>
 #include <mlib/filesystem.h>
@@ -42,6 +42,17 @@ MouseHintAdapter::~MouseHintAdapter()
         gdk_window_get_pointer(event->window, 0, 0, 0);
 }
 
+RGBA::Pixel ColorToPixel(const CR::Color& clr)
+{
+    return RGBA::Pixel(RGBA::Pixel::ToQuant(clr.r), RGBA::Pixel::ToQuant(clr.g),
+                       RGBA::Pixel::ToQuant(clr.b), RGBA::Pixel::ToQuant(clr.a));
+}
+
+void AddUriListTarget(std::list<Gtk::TargetEntry>& targets)
+{
+    targets.push_back(Gtk::TargetEntry(UriListDnDType()));
+}
+
 namespace Editor
 {
 
@@ -70,7 +81,8 @@ Kit::Kit(): standAlone(true)
 
     // * DnD, от браузеров
     std::list<Gtk::TargetEntry> targets;
-    targets.push_back( Project::MediaItemDnDTVTargetEntry() );
+    targets.push_back(Project::MediaItemDnDTVTargetEntry());
+    AddUriListTarget(targets);
     drag_dest_set(targets);
 }
 
@@ -130,12 +142,6 @@ void ClearInitTextVis::Visit(TextObj& t_obj)
     }
 }
 
-RGBA::Pixel ColorToPixel(const CR::Color& clr)
-{
-    return RGBA::Pixel(RGBA::Pixel::ToQuant(clr.r), RGBA::Pixel::ToQuant(clr.g),
-                       RGBA::Pixel::ToQuant(clr.b), RGBA::Pixel::ToQuant(clr.a));
-}
-
 void FillAsEmptyMonitor(RefPtr<Gdk::Pixbuf> canv_pix, Gtk::Widget& wdg)
 {
     //canv_pix->fill(BLACK_CLR);
@@ -246,11 +252,19 @@ void ClearLocalData(MenuRegion& m_rgn, const std::string& tag)
         clear_fnr = bb::bind(&ClearDataWareTag, _1, tag.c_str());
 
     clear_fnr(m_rgn);
-    for( Comp::ListObj::Itr itr = m_rgn.List().begin(), end = m_rgn.List().end(); 
+    for( ListObj::Itr itr = m_rgn.List().begin(), end = m_rgn.List().end(); 
          itr != end; ++itr )
         clear_fnr(**itr);
 }
 
+// временная смена значения
+struct TempBool
+{
+    bool& val;
+    TempBool(bool& val_): val(val_) { val = !val; }
+   ~TempBool() { val = !val; }
+};
+
 void Kit::LoadMenu(Project::Menu menu)
 {
     Project::Menu old_menu = CurMenu();
@@ -284,6 +298,12 @@ void Kit::LoadMenu(Project::Menu menu)
         curMRgn->SetCanvasBuf(this);
 
         mp.editor = this;
+        
+        // * обновление диалога фона
+        Project::BackSettings& bs = curMRgn->bgSet;
+        TempBool tb(bgDlg.userFocus);
+        bgDlg.styleCombo.set_active(bs.bsTyp);
+        SetColor(bgDlg.clrBtn, bs.sldClr);
     }
     else
         curMRgn = 0;
