@@ -38,6 +38,11 @@
 #include <mgui/sdk/menu.h>  // Popup()
 #include <mgui/sdk/widget.h>  // SetColor()
 #include <mgui/gettext.h>
+#include <mgui/dialog.h>
+#include <mgui/sdk/treemodel.h>
+#include <mgui/prefs.h>
+
+#include <mbase/resources.h> // DataDirPath()
 
 //typedef boost::function<bool(Comp::MediaObj*)> CMFunctor;
 //
@@ -52,17 +57,14 @@
 //               break;
 //}
 
-Comp::MediaObj* ToMOTransform(int i) 
+static Comp::MediaObj* GetObj(int i)
 {
-    Comp::ListObj::ArrType& lst = CurMenuRegion().List();
-    Comp::MediaObj* obj = dynamic_cast<Comp::MediaObj*>(lst[i]);
-    ASSERT(obj);
-    return obj;
+    return CurMenuRegion().List()[i];
 }
 
-fe::range<Comp::MediaObj*> SelectedMediaObjs()
+MediaObjRange SelectedMediaObjs()
 {
-    return fe::make_any( MenuEditor().SelArr() | fe::transformed(ToMOTransform) );
+    return fe::make_any( MenuEditor().SelArr() | fe::transformed(GetObj) );
 }
 
 static void SetCursorForEdt(SelActionType typ, Gtk::Widget& wdg);
@@ -176,7 +178,7 @@ class CursorActionVis: public SelVis
 
 static bool SetupCurFrame(FrameThemeObj* obj, MenuRegion&)
 {
-    const std::string& theme = obj->Theme();
+    const FrameTheme& theme = obj->Theme();
     if( theme != Editor::GetActiveTheme() )
     {
         Gtk::ComboBox& combo = MenuToolbar().frame_combo;
@@ -184,7 +186,7 @@ static bool SetupCurFrame(FrameThemeObj* obj, MenuRegion&)
         //for( Gtk::TreeModel::iterator itr = children.begin(), end = children.end();
         //     itr != end; ++itr )
         boost_foreach( const Gtk::TreeRow& row, combo.get_model()->children() )
-            if( row.get_value(Editor::FrameTypeColumn) == theme )
+            if( Editor::Iter2FT(row) == theme )
             {
                 combo.set_active(row);
                 break;
@@ -317,26 +319,6 @@ CalcMouseForData(MEditorArea& edt_area, GdkEventButton* event, int& sel_pos)
     return dat;
 }
 
-static void ForAllSelectedFTO(Editor::FTOFunctor fnr)
-{
-    Editor::ForAllSelectedFTO(fnr);
-}
-
-static bool GetCurPosterLink_(FrameThemeObj* obj, Project::MediaItem& mi, bool& can_set_poster)
-{
-    can_set_poster = true;
-    mi = obj->PosterItem();
-    return false;
-}
-
-static Project::MediaItem GetCurPosterLink(bool& can_set_poster)
-{
-    can_set_poster = false;
-    Project::MediaItem mi;
-    ForAllSelectedFTO( bb::bind(&GetCurPosterLink_, _1, boost::ref(mi), boost::ref(can_set_poster)) );
-    return mi;
-}
-
 static void SetObjectsLinksEx(MEditorArea& edt_area, Project::MediaItem mi, const int_array& items,
                               bool for_poster)
 {
@@ -521,18 +503,22 @@ struct EdgeCalcer
     }
 };
 
+Rect ConvexHull(const fe::range<Comp::MediaObj*>& lst)
+{
+    Rect edge_rct;
+    //ForeachSelectedCM(edt_area, bb::bind(&CalcAlignSettings, _1, boost::ref(edge_rct), boost::ref(is_first)));
+    EdgeCalcer ec(edge_rct);
+    boost_foreach( Comp::MediaObj* obj, lst )
+        ec.Update(obj->Placement());
+    return edge_rct;
+}
+
 typedef boost::function<void(Comp::MediaObj*, const Rect&)> CMFunctor3;
 
 static void AlignByFunctor(const CMFunctor3& fnr)
 {
     MEditorArea& edt_area = MenuEditor();
-    Rect edge_rct;
-    //ForeachSelectedCM(edt_area, bb::bind(&CalcAlignSettings, _1, boost::ref(edge_rct), boost::ref(is_first)));
-    {
-        EdgeCalcer ec(edge_rct);
-        boost_foreach( Comp::MediaObj* obj, SelectedMediaObjs() )
-            ec.Update(obj->Placement());
-    }
+    Rect edge_rct = ConvexHull(SelectedMediaObjs());
 
     AlignVis vis(bb::bind(fnr, _1, edge_rct), edt_area.SelArr());
     RenderByRLV(edt_area, vis);
@@ -615,14 +601,192 @@ static void DistributeImpl(bool is_hz)
     RenderForRegion(edt_area, new_rlr);
 }
 
-static void SetBgColor();
-
 bool SetEnabled(Gtk::Widget& wdg, bool is_enabled)
 {
     wdg.set_sensitive(is_enabled);
     return is_enabled;
 }
 
+static void ReRenderAll(MEditorArea& edt_area)
+{
+    RenderForRegion(edt_area, Rect0Sz(edt_area.FramePlacement().Size()));
+}
+
+void SetBackgroundLink(Project::MediaItem mi)
+{
+    MEditorArea& edt_area = MenuEditor();
+    MenuRegion& mr = edt_area.CurMenuRegion();
+    mr.BgRef().SetLink(mi);
+    ResetBackgroundImage(mr);
+    
+    ReRenderAll(edt_area);
+}
+
+//static void SetBgColor()
+//{
+//    Gtk::ColorSelectionDialog dlg(_("Set Background Color..."));
+//    Gtk::ColorSelection& sel = *dlg.get_colorsel();
+//    RGBA::Pixel& bg_clr      = CurMenuRegion().BgColor();
+//
+//    sel.set_current_color(PixelToColor(bg_clr));
+//    if( dlg.run() == Gtk::RESPONSE_OK )
+//    {
+//        bg_clr = RGBA::ColorToPixel(sel.get_current_color());
+//        SetBackgroundLink(Project::MediaItem()); // очистка + перерисовка
+//    }
+//}
+
+static void ShowBGDialog()
+{
+    Gtk::Window& dlg = MenuEditor().bgDlg.dlg;
+    //if( !dlg.get_visible() )
+    //    dlg.show();
+    dlg.present();
+}
+
+namespace Editor {
+
+// для Project::BackSpanType (заполнение, по размеру, растянуть)
+const char* SpanTypes[] = { N_("Fill"), N_("Fit"), N_("Stretch") };
+
+static void OnResponse(Gtk::Dialog& dlg, int resp)
+{
+    if( resp == Gtk::RESPONSE_CLOSE )
+        dlg.hide();
+}
+
+static void OnBackSettingChanged()
+{
+    MEditorArea& edt_area = MenuEditor();
+    BackgroundDialog& bg = edt_area.bgDlg;
+    // защита от зацикливания по фокусу
+    if( edt_area.CurMenu() && bg.userFocus )
+    {
+        Project::BackSettings& bs = CurMenuRegion().bgSet;
+        bs.bsTyp  = (Project::BackSpanType)bg.styleCombo.get_active_row_number();
+        bs.sldClr = GetColor(bg.clrBtn);
+        
+        ReRenderAll(edt_area);
+    }
+}
+
+typedef Gtk::TreeModelColumn<std::string> StrColumn;
+
+struct IHSFields
+{
+    StrColumn  uriCln;
+
+    IHSFields(Gtk::TreeModelColumnRecord& rec)
+    {
+        rec.add(uriCln);
+    }
+};
+
+static StrColumn& UriColumn()
+{
+    return GetColumnFields<IHSFields>().uriCln;
+}
+
+static void OnIHSGo(Gtk::ComboBox& combo)
+{
+    std::string uri = combo.get_active()->get_value(UriColumn());
+    GoUrl(uri.c_str());
+}
+
+BackgroundDialog::BackgroundDialog(): 
+    dlg(_("Background Settings")), userFocus(true)
+{
+    SetDialogStrict(dlg, 350, -1);
+    DialogVBox& vbox = AddHIGedVBox(dlg);
+    
+    Gtk::ComboBoxText& st_cmb = styleCombo;
+    for( int i=0; i<(int)ARR_SIZE(SpanTypes); i++ )
+        st_cmb.append_text(gettext(SpanTypes[i]));
+    AppendWithLabel(vbox, st_cmb, SMCLN_("_Style"));
+    
+    AppendWithLabel(vbox, clrBtn, SMCLN_("_Color"));
+    
+    // * интерактив
+    st_cmb.signal_changed().connect(&OnBackSettingChanged);
+    clrBtn.signal_color_set().connect(&OnBackSettingChanged);
+    
+    // * интеграция с сервисами картинок
+    StrColumn nam_cln;
+    Gtk::TreeModelColumnRecord& columns = GetColumnRecord<IHSFields>();
+    columns.add(nam_cln);
+    RefPtr<Gtk::ListStore> ihs_store = Gtk::ListStore::create(columns);
+    Gtk::ComboBox& combo = ihsCmb; //NewManaged<Gtk::ComboBox>(ihs_store);
+    combo.set_model(ihs_store);
+
+    // :TODO: refactor
+    io::stream strm(DataDirPath("ihslist.lst").c_str(), iof::in);
+    std::string line_str;
+    for( int i=0; std::getline(strm, line_str); i++ )
+    {
+        const char* name  = line_str.c_str();
+        const char* space = strchr(name, ' ');
+        std::string uri   = space ? std::string(name, space) : line_str ;
+        std::string title = std::string(space ? space+1 : name);
+
+        Gtk::TreeRow row = *ihs_store->append();
+        row[UriColumn()] = uri;
+        row[nam_cln] = title;
+        if( i == UnnamedPrefs().ihsNum )
+            combo.set_active(i);
+    }
+
+    Gtk::VBox& vb = PackStart(vbox, NewManaged<Gtk::VBox>());
+    PackStart(vb, LabelForWidget(SMCLN_("Go to online image service in web browser"), combo));
+    Gtk::HBox& hbox = PackCompositeWdg(combo);
+    SetTip(hbox, _("You can drop background image you like from a web browser directly onto Menu Editor"));
+    combo.pack_start(nam_cln);
+    PackCompositeWdgButton(hbox, Gtk::Stock::APPLY, bb::bind(&OnIHSGo, b::ref(combo)));
+    PackStart(vb, hbox);
+
+    // сам по умолчанию скрыт
+    CompleteDialog(dlg, true);
+    dlg.signal_response().connect(bb::bind(&OnResponse, b::ref(dlg), _1));
+}
+
+BackgroundDialog::~BackgroundDialog()
+{
+    UnnamedPrefs().ihsNum = ihsCmb.get_active_row_number();
+}
+
+} // namespace Editor
+
+FrameThemeObj* ToRealFTOTransform(int i) 
+{
+    FrameThemeObj* obj = dynamic_cast<FrameThemeObj*>(GetObj(i));
+    if( obj && IsIconTheme(*obj) )
+        obj = 0;
+    return obj;
+}
+
+static bool IsNotNull(const FrameThemeObj* fto)
+{
+    return fto;
+}
+
+fe::range<FrameThemeObj*> SelectedRealFTOs()
+{
+    return fe::make_any( MenuEditor().SelArr() | fe::transformed(ToRealFTOTransform) | fe::filtered(IsNotNull) );
+}
+
+static void OnHighlightBorder(Gtk::CheckMenuItem& hib_itm)
+{
+    bool is_on = hib_itm.get_active();
+    boost_foreach( FrameThemeObj* obj, SelectedRealFTOs() )
+        obj->hlBorder = is_on;
+}
+
+void AddImageItem(Gtk::Menu& menu, const Gtk::StockID& id, const ActionFunctor& fnr, bool is_enabled)
+{
+    Gtk::MenuItem& itm = AppendMI(menu, NewManaged<Gtk::ImageMenuItem>(id));
+    itm.set_sensitive(is_enabled);
+    itm.signal_activate().connect(fnr);
+}
+
 void NormalSelect::OnMouseDown(MEditorArea& edt_area, GdkEventButton* event)
 {
     int sel_pos;
@@ -659,6 +823,11 @@ void NormalSelect::OnMouseDown(MEditorArea& edt_area, GdkEventButton* event)
         bool has_selected = !sel_arr.empty();
         Gtk::Menu& mn     = NewPopupMenu(); 
 
+        // :TODO: клавиатурные сочетания сделать + отобразить в меню
+        AddImageItem(mn, Gtk::Stock::CUT,   bb::bind(&OnEditorCopy, true), has_selected);
+        AddImageItem(mn, Gtk::Stock::COPY,  bb::bind(&OnEditorCopy, false), has_selected);
+        AddImageItem(mn, Gtk::Stock::PASTE, bb::bind(&OnEditorPaste, Point(event->x, event->y)), CopyList.size());
+        
         AddEnabledItem(mn, _("Delete"), &DeleteSelObjects, has_selected);
         AppendSeparator(mn);
 
@@ -684,17 +853,32 @@ void NormalSelect::OnMouseDown(MEditorArea& edt_area, GdkEventButton* event)
         AddEnabledItem(mn, _("Remove Link"), MakeActionLinker(Project::MediaItem()),
                        has_selected);
 
+        Project::MediaItem cur_pstr;
+        bool has_fto = false;
+        bool is_hib  = false;
+        boost_foreach( FrameThemeObj* obj, SelectedRealFTOs() )
+        {
+            has_fto = true;
+            is_hib  = obj->hlBorder;
+            cur_pstr = obj->PosterItem();
+            break;
+        }
+        if( !has_selected )
+            cur_pstr = CurMenuRegion().BgRef();
+                
         // Poster Link
         Gtk::MenuItem& poster_itm = MakeAppendMI(mn, _("Set Poster"));
-        Project::MediaItem cur_pstr;
-        bool can_set_poster = true;
-        if( has_selected )
-            cur_pstr = GetCurPosterLink(can_set_poster);
-        else
-            cur_pstr = CurMenuRegion().BgRef();
-        if( SetEnabled(poster_itm, can_set_poster) )
+        if( SetEnabled(poster_itm, (!has_selected || has_fto)) )
             poster_itm.set_submenu(PosterMenuBuilder(cur_pstr, edt_area, !has_selected).Create());
 
+        Gtk::CheckMenuItem& hib_itm = NewManaged<Gtk::CheckMenuItem>(_("Highlight Border Only"));
+        mn.append(hib_itm);
+        if( SetEnabled(hib_itm, has_fto) )
+        {    
+            hib_itm.set_active(is_hib);
+            hib_itm.signal_toggled().connect(bb::bind(&OnHighlightBorder, b::ref(hib_itm)));
+        }
+            
         // Align
         {
             Gtk::MenuItem& align_itm = MakeAppendMI(mn, _("Align"));
@@ -720,8 +904,9 @@ void NormalSelect::OnMouseDown(MEditorArea& edt_area, GdkEventButton* event)
             }
         }
 
-        // Set Background Color
-        AddEnabledItem(mn, _("Set Background Color..."), &SetBgColor, !has_selected);
+        // Фон
+        //AddEnabledItem(mn, _("Set Background Color..."), &SetBgColor, !has_selected);
+        AddEnabledItem(mn, DOTS_("Background Settings"), &ShowBGDialog, !has_selected);
 
         //mn.accelerate(edt_area);
         Popup(mn, event, true);
@@ -903,32 +1088,62 @@ void SelRectVis::RedrawMO(Manager ming)
         Draw(ming); 
 }
 
-static void DeleteSelObjects()
+void AppendObjIndex(int_array& arr, Comp::MediaObj* obj, const ListObj::ArrType& lst)
+{
+    ListObj::ArrType::const_iterator beg = lst.begin(), end = lst.end();
+    ListObj::ArrType::const_iterator it = std::find(beg, end, obj);
+    ASSERT( it != end );
+    arr.push_back(it - beg);
+}
+
+void DeleteObjects(const int_array& del_nums, RectListRgn& rct_lst)
 {
     MEditorArea& edt_area = MenuEditor();
-    typedef Comp::ListObj::ArrType ArrType;
+    typedef ListObj::ArrType ArrType;
     MenuRegion& rgn    = edt_area.CurMenuRegion();
     int_array& sel_arr = edt_area.SelArr();
     ArrType&       lst = rgn.List();
     // * узнаем где отрисовывать
-    SelRectVis sr_vis(sel_arr);
+    SelRectVis sr_vis(del_nums);
     rgn.Accept(sr_vis);
     // * удаляем объекты
     ArrType new_lst;
-    ArrType::iterator itr = lst.begin();
+    ArrType new_sel_lst;
     for( int i=0; i<(int)lst.size(); ++i )
     {
-        Comp::Object* obj = lst[i];
-        if( IsInArray(i, sel_arr) )
-            delete obj;
+        Comp::MediaObj* obj = lst[i];
+        if( IsInArray(i, del_nums) )
+            Destroy(obj);
         else
+        {    
             new_lst.push_back(obj);
+            if( IsInArray(i, sel_arr) )
+                new_sel_lst.push_back(obj);
+        }
     }
     lst.swap(new_lst);
-    // * чистим выделение
+    // * обновляем выделение
     sel_arr.clear();
-    // * перерисовываем
-    RenderForRegion(edt_area, sr_vis.RectList());
+    boost_foreach( Comp::MediaObj* obj, new_sel_lst )
+        AppendObjIndex(sel_arr, obj, lst);
+    
+    rct_lst.swap(sr_vis.RectList());
+}
+
+static void DeleteSelObjects()
+{
+    MEditorArea& edt_area = MenuEditor();
+    RectListRgn rct_lst;
+    DeleteObjects(edt_area.SelArr(), rct_lst);
+    RenderForRegion(edt_area, rct_lst);
+}
+
+void ClearFTOCache(FrameThemeObj& fto)
+{
+    if( IsIconTheme(fto) )
+        ClearDwPixbuf(fto);
+    else
+        fto.GetData<FTOInterPixData>().ClearPix();
 }
 
 void ClearLinkVis::Visit(FrameThemeObj& fto)
@@ -941,7 +1156,7 @@ void ClearLinkVis::Visit(FrameThemeObj& fto)
         if( old_mi != Project::MIToDraw(fto) )
         {
             // нужна перерисовка
-            fto.GetData<FTOInterPixData>().ClearPix();
+            ClearFTOCache(fto);
             MyParent::Visit(fto);
         }
     }
@@ -954,37 +1169,6 @@ void ClearLinkVis::Visit(TextObj& t_obj)
     //MyParent::Visit(t_obj);
 }
 
-void SetBackgroundLink(Project::MediaItem mi)
-{
-    MEditorArea& edt_area = MenuEditor();
-    MenuRegion& mr = edt_area.CurMenuRegion();
-    mr.BgRef().SetLink(mi);
-    ResetBackgroundImage(mr);
-    RenderForRegion(edt_area, Rect0Sz(edt_area.FramePlacement().Size()));
-}
-
-//void SetSelObjectsLinks(Project::MediaItem mi, bool is_background)
-//{
-//    if( is_background )
-//        SetBackgroundLink(mi);
-//    else
-//        SetObjectsLinks(mi, false);
-//}
-
-static void SetBgColor()
-{
-    Gtk::ColorSelectionDialog dlg(_("Set Background Color..."));
-    Gtk::ColorSelection& sel = *dlg.get_colorsel();
-    RGBA::Pixel& bg_clr      = CurMenuRegion().BgColor();
-
-    sel.set_current_color(PixelToColor(bg_clr));
-    if( dlg.run() == Gtk::RESPONSE_OK )
-    {
-        bg_clr = RGBA::ColorToPixel(sel.get_current_color());
-        SetBackgroundLink(Project::MediaItem()); // очистка + перерисовка
-    }
-}
-
 class SelTextRefontVis: public CommonDrawVis
 {
     typedef CommonDrawVis MyParent;
@@ -1100,8 +1284,7 @@ class MoveVis: public CommonDrawVis //RectListVis
 
 void MoveVis::CalcMoveVector()
 {
-    const Planed::Transition& tr = menuRgn->Transition();
-    lct = tr.RelToAbs( (tr.DevToRel(lct)) );
+    lct = DevToAbs(menuRgn->Transition(), lct);
     // вектор перемещения
     lct = lct - origPnt;
 }
@@ -1122,10 +1305,67 @@ class RepositionVis: public MoveVis
             void  RepositionObj(Comp::MediaObj& m_obj, Manager ming);
 };
 
+static bool IsSnapToGrid()
+{
+    return IsSnapToGrid(MenuEditor());
+}
+
+static bool DoGridSnap(int& coord)
+{
+    bool res = true;
+    int val = coord % GRID_STEP;
+    const int gs3 = GRID_STEP / 3;
+    
+    if( val <= gs3 )
+        coord -= val;
+    else if( val >= GRID_STEP - gs3 )
+        coord += GRID_STEP - val;
+    else
+        // нет прилипания
+        res = false;
+    return res;
+}
+
+typedef int Point::* PointAttr;
+
+static void UpdateSnap(bool& has_snap, int new_shift, Point& lct, const Point& orig_lct,
+                       PointAttr pa)
+{
+    if( !has_snap || (std::abs(new_shift - orig_lct.*pa) < std::abs(lct.*pa - orig_lct.*pa)) )
+    {    
+        lct.*pa = new_shift;
+        has_snap = true;
+    }
+}
+
 void RepositionVis::VisitImpl(MenuRegion& menu_rgn)
 {
     if( menu_rgn.FramePlacement().Contains(lct) )
+    {    
         CalcMoveVector();
+        if( IsSnapToGrid() )
+        {
+            const Point orig_lct = lct;
+            bool has_x_snap = false;
+            bool has_y_snap = false;
+            boost_foreach( Comp::MediaObj* obj, SelectedMediaObjs() )
+            {
+                const Rect& plc = obj->Placement();
+                Rect nplc = plc + orig_lct;
+                
+                if( DoGridSnap(nplc.lft) )
+                    UpdateSnap(has_x_snap, nplc.lft - plc.lft, lct, orig_lct, &Point::x);
+                if( DoGridSnap(nplc.rgt) )
+                    UpdateSnap(has_x_snap, nplc.rgt - plc.rgt, lct, orig_lct, &Point::x);
+                
+                if( DoGridSnap(nplc.top) )
+                    UpdateSnap(has_y_snap, nplc.top - plc.top, lct, orig_lct, &Point::y);
+                if( DoGridSnap(nplc.btm) )
+                    UpdateSnap(has_y_snap, nplc.btm - plc.btm, lct, orig_lct, &Point::y);
+                                
+            }
+        }
+    }
     else
         lct = Point(0, 0); // за пределы редактора не хотим выходить
 
@@ -1238,21 +1478,50 @@ void GetBasePointExt(Point& res, const Rect& plc, SelActionType cur_typ, Point&
     }
 }
 
-struct SizeVectorData: public DWConstructorTag
+struct SizeVectorData
 {
     typedef std::pair<double, double> DblPoint;
-    DblPoint vecPnt;
+    DblPoint  vecPnt;
+      double  ratio;
 
-              SizeVectorData(DataWare&): vecPnt(0,0) {}
+              SizeVectorData(): vecPnt(0,0) {}
 
         void  Set(Point& sz, Point& bas_vec)
               {
                   vecPnt.first  = bas_vec.x ? (double)sz.x/bas_vec.x : 0 ;
                   vecPnt.second = bas_vec.y ? (double)sz.y/bas_vec.y : 0 ;
+                  
+                  ASSERT_RTL( sz.y );
+                  ratio = sz.x / (double)sz.y;
               }
         void  CalcPlacement(Rect& plc, Point& lct);
 };
 
+static bool IsLftResize(SizeVectorData::DblPoint& vec_pnt)
+{
+    return vec_pnt.first < 0;
+}
+
+static bool IsRgtResize(SizeVectorData::DblPoint& vec_pnt)
+{
+    return vec_pnt.first > 0;
+}
+
+static bool IsTopResize(SizeVectorData::DblPoint& vec_pnt)
+{
+    return vec_pnt.second < 0;
+}
+
+static bool IsBtmResize(SizeVectorData::DblPoint& vec_pnt)
+{
+    return vec_pnt.second > 0;
+}
+
+static bool IsHzResize(SizeVectorData::DblPoint& vec_pnt)
+{
+    return vec_pnt.first;
+}
+
 static void CheckMinSz(int& len)
 {
     len = std::max(len, 10);
@@ -1262,7 +1531,7 @@ void SizeVectorData::CalcPlacement(Rect& plc, Point& lct)
 {
     // 1 размер
     Point sz = plc.Size();
-    if( vecPnt.first ) sz.x  = int(vecPnt.first *lct.x);
+    if( IsHzResize(vecPnt) ) sz.x  = int(vecPnt.first *lct.x);
     if( vecPnt.second ) sz.y = int(vecPnt.second*lct.y);
 
     CheckMinSz(sz.x);
@@ -1270,14 +1539,57 @@ void SizeVectorData::CalcPlacement(Rect& plc, Point& lct)
 
     // 2 lt-точка
     Point lt_pnt;
-    lt_pnt.x = (vecPnt.first  >= 0) ? plc.lft : plc.rgt - sz.x ;
-    lt_pnt.y = (vecPnt.second >= 0) ? plc.top : plc.btm - sz.y ;
+    lt_pnt.x = IsLftResize(vecPnt) ? plc.rgt - sz.x : plc.lft ;
+    lt_pnt.y = IsTopResize(vecPnt) ? plc.btm - sz.y : plc.top ;
 
     // 3 - результат
     plc.lft = lt_pnt.x;
     plc.top = lt_pnt.y;
     plc.rgt = lt_pnt.x + sz.x;
     plc.btm = lt_pnt.y + sz.y;
+    
+    if( IsSnapToGrid() )
+    {
+        // :TRICKY: в отличие от перемещения объектов здесь привязка
+        // идет по каждому объекту отдельно (а не группы), что не идеально;
+        // однако последующая реализация фичи сохранения пропорций будет
+        // конфиктовать с прилипанием => сохранение пропорций важнее, считаем =>
+        // оставляем как есть
+        
+        if( IsLftResize(vecPnt) )
+            DoGridSnap(plc.lft);
+        if( IsRgtResize(vecPnt) )
+            DoGridSnap(plc.rgt);
+        if( IsTopResize(vecPnt) )
+            DoGridSnap(plc.top);
+        if( IsBtmResize(vecPnt) )
+            DoGridSnap(plc.btm);
+    }
+    
+    // сохранение пропорций с Shift
+    if( GetKeyboardState() & GDK_SHIFT_MASK )
+    {
+        sz = plc.Size();
+
+        if( IsHzResize(vecPnt) )
+        {    
+            int hgt = Round(sz.x / ratio);
+            CheckMinSz(hgt);
+            if( IsTopResize(vecPnt) )
+                plc.top = plc.btm - hgt;
+            else
+                plc.btm = plc.top + hgt;
+        }
+        else
+        {
+            int wdh = Round(ratio * sz.y);
+            CheckMinSz(wdh);
+            if( IsLftResize(vecPnt) )
+                plc.lft = plc.rgt - wdh;
+            else
+                plc.rgt = plc.lft + wdh;
+        }
+    }
 }
 
 void SetVectorVis::Visit(Comp::MediaObj& mo)
