@@ -36,6 +36,13 @@ C_LINKAGE_END
 
 #include <boost/noncopyable.hpp>
 
+// :TRICKY: для сборок со старыми версиями ffmpeg ~ 0.5
+#if (LIBAVCODEC_VERSION_MAJOR < 53) && !defined(AVMEDIA_TYPE_AUDIO)
+#define AVMEDIA_TYPE_AUDIO      CODEC_TYPE_AUDIO
+#define AVMEDIA_TYPE_VIDEO      CODEC_TYPE_VIDEO
+#endif
+
+
 // иначе импорт только DVD-совместимых файлов 
 #define FFMPEG_IMPORT_POLICY 1
 
@@ -78,8 +85,6 @@ struct FFInfo: public FFData
     ~FFInfo();
 };
 
-bool CanOpenAsFFmpegVideo(const char* fname, std::string& err_str);
-
 struct FFViewer: public FFData
 {
                      // время текущего кадра
@@ -102,8 +107,19 @@ struct FFViewer: public FFData
 
 AVCodecContext* GetVideoCtx(FFData& ffv);
 
-// однострочная настройка
-std::string PrefContents(const char* fname);
+std::string GetFirstLine(const std::string& text);
+std::string GetFileFirstLine(const std::string& fname);
+
+// в дополнение к отрицательному значению OpenInfo()
+struct FFDiagnosis
+{
+    std::string  errStr;
+           bool  isElemStream; // элементарный видеопоток
+
+    FFDiagnosis(): isElemStream(false) {}
+};
+
+bool OpenInfo(FFData& ffi, const char* fname, FFDiagnosis& diag);
 
 #endif // #ifndef __MGUI_FFVIEWER_H__
 
