@@ -142,8 +142,13 @@ void CheckVideoFormat(ErrorDesc& ed, const Mpeg::SequenceData& vid, bool is_ntsc
     std::string frate_list;
     if( is_ntsc )
     {
-        frate_ok = frate == Point(24, 1) || frate == Point(30000, 1001);
-        frate_list = FpsToStr(Point(24, 1)) + ", " + FpsToStr(Point(30000, 1001));
+        // :TRICKY: ffmpeg -target film-dvd does 24000/1001; it is not good for DVD-Video
+        // (only 30000/1001 is) though:
+        // - TSUNAMI reject it
+        // - xine stutters with it
+        // , but some players accept (and people want) it - the ticket #85
+        frate_ok = frate == Point(24000, 1001) || frate == Point(30000, 1001);
+        frate_list = FpsToStr(Point(24000, 1001)) + ", " + FpsToStr(Point(30000, 1001));
     }
     else
     {
@@ -420,7 +425,7 @@ void TryAddMediaQuiet(const std::string& fname, const std::string& desc)
 static std::string StandFNameOut(const fs::path& pth)
 {
     return "<span style=\"italic\" underline=\"low\">" + 
-                    pth.leaf() + "</span>";
+        fs::name_str(pth) + "</span>";
 }
 
 #if GTK_CHECK_VERSION(2,18,0)
@@ -454,7 +459,7 @@ StorageItem CheckExists(const fs::path& pth, RefPtr<MediaStore> ms)
 
 void OneMediaError(const fs::path& err_pth, const std::string& desc)
 {
-    AddMediaError(BF_("Can't add file \"%1%\".") % err_pth.leaf() % bf::stop, desc);
+    AddMediaError(BF_("Can't add file \"%1%\".") % fs::name_str(err_pth) % bf::stop, desc);
 }
 
 void TryAddMedias(const Str::List& paths, MediaBrowser& brw,
@@ -465,7 +470,7 @@ void TryAddMedias(const Str::List& paths, MediaBrowser& brw,
     {
         const std::string fname = paths[0];
         fs::path pth(fname); 
-        std::string leaf = pth.leaf();
+        std::string leaf = fs::name_str(pth);
         {
             static re::pattern dvd_video_vob("(VIDEO_TS|VTS_[0-9][0-9]_[0-9]).VOB", 
                                               re::pattern::perl|re::pattern::icase);
