@@ -76,14 +76,9 @@ void OpenPublishMenu(const Gtk::TreeIter& itr, RefPtr<MenuStore> ms, Menu mn)
     PublishMenu(itr, ms, mn);
 }
 
-void InsertMenuIntoBrowser(MenuBrowser& brw)
+void InsertMenuIntoBrowser(MenuBrowser& brw, Menu mn)
 {
     RefPtr<MenuStore> ms = brw.GetMenuStore();
-    // * subj
-    Menu mn = MakeMenu(Size(ms));
-    // отношение сторон
-    mn->Params().GetAF() = IsMenuToBe4_3() ? af4_3 : af16_9 ;
-
     // * куда
     Gtk::TreeRow row = *InsertByPos(ms, GetCursor(brw));
     OpenPublishMenu(row, ms, mn);
@@ -93,6 +88,14 @@ void InsertMenuIntoBrowser(MenuBrowser& brw)
     GoToPos(brw, ms->get_path(row));
 }
 
+Menu MakeMenu(const std::string& name, AspectFormat af)
+{
+    Menu mn = MakeMenu(name);
+    // отношение сторон
+    mn->Params().GetAF() = af;
+    return mn;
+}
+
 // расчет областей отрисовки при изменении содержимого (первичного медиа)
 class RegionEraserVis: public GuiObjVisitor
 {
@@ -167,7 +170,7 @@ void RegionEraserVis::Visit(FrameThemeObj& fto)
     if( lnk.Link() == MIToDraw(fto) )
     {
         // * добавляем область
-        plc = Planed::AbsToRel(mPack.thRgn.Transition(), fto.Placement());
+        plc = RelPos(fto, mPack.thRgn.Transition());
         // * обнуляем
         Editor::FTOData& dat = mPack.editor ? fto.GetData<FTOInterPixData>() : 
             (Editor::FTOData&)fto.GetData<FTOThumbData>() ;
