@@ -38,6 +38,8 @@
 #include <mgui/win_utils.h>
 #include <mgui/key.h>
 
+#include <mbase/project/table.h> // MakeMenu()
+
 #include <mlib/sdk/logger.h>
 #include <mlib/sigc.h>
 
@@ -440,13 +442,28 @@ DialogParams MenuSettingsDialog(Menu mn, Gtk::Widget* par_wdg)
                         420, par_wdg);
 }
 
+static void CopyMenu(Menu orig_mn, ObjectBrowser& brw)
+{
+    std::string name = BF_("%1% copy") % orig_mn->mdName % bf::stop;
+    Menu mn = MakeMenu(name, orig_mn->Params().GetAF());
+
+    mn->MtnData() = orig_mn->MtnData();
+    mn->subPal    = orig_mn->subPal;
+    SaveMenu(mn, orig_mn);
+    
+    InsertMenuIntoBrowser(static_cast<MenuBrowser&>(brw), mn);
+}
+
 static void OnRightButton(ObjectBrowser& brw, MediaItem mi, GdkEventButton* event)
 {
     Menu mn = IsMenu(mi);
     ASSERT(mn);
 
     Gtk::Menu& gmn = NewPopupMenu();
+    AppendRenameAction(gmn, brw);
+    AddEnabledItem(gmn, _("Copy Menu"), bb::bind(&CopyMenu, mn, b::ref(brw)));
     AddDialogItem(gmn, MenuSettingsDialog(mn, &brw));
+    
     Popup(gmn, event, true);
 }
 
@@ -454,25 +471,15 @@ MenuBrowser::MenuBrowser(RefPtr<MenuStore> ms)
 {
     set_name("MenuBrowser");
     set_model(ms);
-    SetupBrowser(*this, ms->columns.menu.index());
+    SetupBrowser(*this, ms->columns.menu.index(), false);
 
     const MenuStore::TrackFields& trk_fields = ms->columns;
 
     // 1 миниатюра + имя
-    {
-        Gtk::TreeView::Column& name_cln = NewManaged<Gtk::TreeView::Column>(Glib::ustring("Name"));
-        name_cln.pack_start(trk_fields.thumbnail, false);
-
-        // 2 имя
-        Gtk::CellRendererText& rndr = NewManaged<Gtk::CellRendererText>();
-
-        rndr.property_size_points() = 13.0; // синхронизировать со стилем "MenuEntryStyle"
-        rndr.property_xpad() = 5;
-        //rndr.property_weight() = PANGO_WEIGHT_BOLD;
-        SetupNameRenderer(name_cln, rndr, ms);
-
-        append_column(name_cln);
-    }
+    Gtk::CellRendererText& rndr = AppendNameColumn(*this, trk_fields.thumbnail, false, ms);
+    rndr.property_size_points() = 13.0; // синхронизировать со стилем "MenuEntryStyle"
+    rndr.property_xpad() = 5;
+    //rndr.property_weight() = PANGO_WEIGHT_BOLD;
 
     SetOnRightButton(*this, bb::bind(&OnRightButton, _1, _2, _3));
 }
@@ -650,7 +657,8 @@ Gtk::Menu& CommonMenuBuilder::Create()
     }
 
     // * Medias
-    if( Size(mdStore) )
+    // :TRICKY: mdStore может быть нулем в тесте test_meditor.cpp
+    if( mdStore && Size(mdStore) )
     {
         for( MediaStore::iterator itr = mdStore->children().begin(), end = mdStore->children().end();
              itr != end; ++itr )
@@ -714,6 +722,12 @@ Gtk::Menu& CommonMenuBuilder::Create()
 //    slm.linkMenu = &LinkMenuBuilder(slm, *mp.editor).Create();
 //}
 
+void OnNewMenu(MenuBrowser& brw)
+{
+    Menu mn = MakeMenu(MenuAutoName(MenusCnt()), IsMenuToBe4_3() ? af4_3 : af16_9);
+    InsertMenuIntoBrowser(brw, mn);
+}
+
 void PackMenusWindow(Gtk::Container& contr, RefPtr<MenuStore> ms, RefPtr<MediaStore> md_store)
 {
     MenuBrowser& menu_brw = NewManaged<MenuBrowser>(ms);
@@ -754,7 +768,7 @@ void PackMenusWindow(Gtk::Container& contr, RefPtr<MenuStore> ms, RefPtr<MediaSt
             Gtk::Button* add_btn = CreateButtonWithIcon("", Gtk::Stock::ADD,
                                                         _("Add Menu"));
             hb.pack_start(*add_btn);
-            add_btn->signal_clicked().connect(bb::bind(&InsertMenuIntoBrowser, boost::ref(menu_brw)));
+            add_btn->signal_clicked().connect(bb::bind(&OnNewMenu, boost::ref(menu_brw)));
 
             Gtk::Button* rm_btn = CreateButtonWithIcon("", Gtk::Stock::REMOVE,
                                                        _("Remove Menu"));
@@ -775,7 +789,7 @@ void PackMenusWindow(Gtk::Container& contr, RefPtr<MenuStore> ms, RefPtr<MediaSt
         vbox.pack_start(MakeTitleLabel(_("Media List")), Gtk::PACK_SHRINK);
         PackHSeparator(vbox);
 
-        MediaBrowser& brw = NewManaged<MediaBrowser>(md_store);
+        MediaBrowser& brw = NewManaged<MediaBrowser>(md_store, false);
         vbox.pack_start(brw);
     }
 
@@ -796,5 +810,20 @@ void PackMenusWindow(Gtk::Container& contr, RefPtr<MenuStore> ms, RefPtr<MediaSt
 
 }
 
+static RefPtr<Project::MenuStore> GetMenuStore()
+{
+    return GetAStores().mnStore;
+}
+
+static Menu ToMenuTransform(const Gtk::TreeRow& row) 
+{
+    return GetMenu(GetMenuStore(), row);
+}
+
+fe::range<Menu> AllMenus()
+{
+    return fe::make_any( GetMenuStore()->children() | fe::transformed(ToMenuTransform) );
+}
+
 } // namespace Project
 
