@@ -27,11 +27,11 @@
 #include <mgui/editor/render.h>
 #include <mgui/editor/text.h>
 #include <mgui/editor/kit.h>
+#include <mgui/editor/bind.h> // DoRenderFTO()
 
 #include <mgui/author/script.h> // IsMotion()
 #include <mgui/img-factory.h>
 
-#include <mbase/project/theme.h> // ThemeOrDef()
 #include <mbase/project/srl-common.h> // MakeColor()
 #include <mlib/sdk/logger.h>
 #include <mdemux/util.h>         // Mpeg::set_hms
@@ -62,7 +62,6 @@ class ThumbRenderVis: public CommonRenderVis
     public:
                   ThumbRenderVis(RectListRgn& r_lst): MyParent(r_lst) { }
 
-   //virtual  void  VisitImpl(MenuRegion& menu_rgn);
    virtual RefPtr<Gdk::Pixbuf> CalcBgShot();
    virtual  void  Visit(FrameThemeObj& fto);
 };
@@ -84,11 +83,8 @@ RefPtr<Gdk::Pixbuf> FTOThumbData::CalcSource(Project::MediaItem mi, const Point&
 
 void ThumbRenderVis::Visit(FrameThemeObj& fto)
 {
-    Rect rel_plc = CalcRelPlacement(fto.Placement());
-
-    // используем кэш
     FTOThumbData& pix_data = fto.GetData<FTOThumbData>();
-    drw->CompositePixbuf(pix_data.GetPix(), rel_plc);
+    DoRenderFTO(drw.get(), fto, pix_data, cnvBuf->Transition());
 }
 
 CommonRgnListCleaner::CommonRgnListCleaner(CanvasBuf& cnv_buf): cnvBuf(cnv_buf) 
@@ -267,7 +263,7 @@ static void LoadBackground(MenuRegion& menu_rgn, Menu mn)
     menu_rgn.GetParams()   = prms;
     menu_rgn.BgRef().SetLink(mn->BgRef());
 
-    menu_rgn.BgColor() = MakeColor(mn->Color());
+    menu_rgn.bgSet = mn->bgSet;
     menu_rgn.BgColor().alpha = RGBA::Pixel::MaxClr; // форсируем непрозрачность
 
 //     SimpleOverObj* bg_soo  = new SimpleOverObj;
@@ -278,35 +274,38 @@ static void LoadBackground(MenuRegion& menu_rgn, Menu mn)
 //     menu_rgn.Ins(*bg_soo);
 }
 
-static void LoadMenuItem(Comp::MediaObj* obj, MenuItem mi)
+TextObj* CreateEditorText(const std::string& text, Editor::TextStyle style, const Rect& plc)
 {
-    obj->MediaItem().SetLink(mi->Ref());
-    obj->PlayAll() = mi->playAll;
-}
-
-TextObj* CreateEditorText(TextItemMD& txt_md)
-{
-    std::string text = txt_md.mdName;
-    ASSERT( !text.empty() );
-
     TextObj* obj = new TextObj;
 
-    Editor::TextStyle style(Pango::FontDescription(txt_md.FontDesc()), txt_md.IsUnderlined(), 
-                            MakeColor(txt_md.Color()));
     MEdt::CheckDescNonNull(style);
-    obj->Load(text, txt_md.Placement(), style);
-
-    LoadMenuItem(obj, &txt_md);
-
+    obj->Load(text, plc, style);
     return obj;
 }
 
-FrameThemeObj* NewFTO(const std::string& theme, const Rect& lct)
+FrameThemeObj* NewFTO(const FrameTheme& theme, const Rect& lct)
 {
-    return new FrameThemeObj(Project::ThemeOrDef(theme).c_str(), lct);
+    FrameTheme ft = theme;
+    // защита от пустых данных
+    if( ft.themeName.empty() )
+    {
+        ft.isIcon    = false;    
+        ft.themeName = "rect";
+    }
+    return new FrameThemeObj(ft, lct);
 }
 
-void AddMenuItem(MenuRegion& menu_rgn, Comp::Object* obj)
+FrameThemeObj* CreateNewFTO(const FrameTheme& theme, const Rect& lct, MediaItem p_mi, 
+                            bool hl_border)
+{
+    FrameThemeObj* fto = NewFTO(theme, lct);
+    fto->PosterItem().SetLink(p_mi);
+    fto->hlBorder = hl_border;
+    
+    return fto;
+}
+
+void AddMenuItem(MenuRegion& menu_rgn, Comp::MediaObj* obj)
 {
     menu_rgn.Ins(*obj);
     SetOwnerMenu(obj, GetOwnerMenu(&menu_rgn));
@@ -319,6 +318,13 @@ void ClearMenuSavedData(Menu mn)
     mn->List().clear();
 }
 
+static void LoadAddMI(MenuRegion& menu_rgn, Comp::MediaObj* obj, MenuItem mi)
+{
+    obj->MediaItem().SetLink(mi->Ref());
+    obj->PlayAll() = mi->playAll;
+    AddMenuItem(menu_rgn, obj);
+}
+
 void LoadMenu(MenuRegion& menu_rgn, Menu mn)
 {
     ASSERT( mn );
@@ -335,15 +341,20 @@ void LoadMenu(MenuRegion& menu_rgn, Menu mn)
         MenuItem mi = *itr;
         if( TextItemMD* txt_mi = dynamic_cast<TextItemMD*>(mi.get()) )
         {
-            TextObj* txt_obj = CreateEditorText(*txt_mi);
-            AddMenuItem(menu_rgn, txt_obj);
+            std::string text = txt_mi->mdName;
+            ASSERT( !text.empty() );
+
+            Editor::TextStyle style(Pango::FontDescription(txt_mi->FontDesc()), txt_mi->IsUnderlined(), 
+                                    MakeColor(txt_mi->Color()));
+            TextObj* txt_obj = CreateEditorText(text, style, txt_mi->Placement());
+            
+            LoadAddMI(menu_rgn, txt_obj, txt_mi);
         }
         else if( FrameItemMD* frame_mi = dynamic_cast<FrameItemMD*>(mi.get()) )
         {
-            FrameThemeObj* fto = NewFTO(frame_mi->Theme(), frame_mi->Placement());
-            LoadMenuItem(fto, frame_mi);
-            fto->PosterItem().SetLink(frame_mi->Poster());
-            AddMenuItem(menu_rgn, fto);
+            FrameThemeObj* fto = CreateNewFTO(frame_mi->Theme(), frame_mi->Placement(),
+                                              frame_mi->Poster(), frame_mi->hlBorder);
+            LoadAddMI(menu_rgn, fto, frame_mi);
         }
         else
             ASSERT(0);
@@ -359,15 +370,14 @@ void SaveMenuItem(MenuItem mi, Comp::MediaObj* m_obj)
     mi->playAll     = m_obj->PlayAll();
 }
 
-void SaveMenu(Menu mn)
+void SaveMenu(Menu mn, Menu orig_mn)
 {
-    ASSERT( mn );
-    MenuRegion& m_rgn = GetMenuRegion(mn);
-
+    ASSERT( mn && orig_mn );
+    MenuRegion& m_rgn = GetMenuRegion(orig_mn);
     // * меню
     mn->Params() = m_rgn.GetParams();
     mn->BgRef()  = m_rgn.BgRef();
-    mn->Color()  = ToString(m_rgn.BgColor());
+    mn->bgSet    = m_rgn.bgSet;
 
     MenuItem mi;
     for( MenuRegion::Itr itr = m_rgn.List().begin(), end = m_rgn.List().end(); itr != end; ++itr )
@@ -387,8 +397,9 @@ void SaveMenu(Menu mn)
         else if( FrameThemeObj* frame_obj = dynamic_cast<FrameThemeObj*>(obj) )
         {
             FrameItemMD* f_itm = new FrameItemMD(mn.get());
-            f_itm->Theme()    = frame_obj->Theme();
-            f_itm->Poster()   = frame_obj->PosterItem();
+            f_itm->Theme()  = frame_obj->Theme();
+            f_itm->Poster() = frame_obj->PosterItem();
+            f_itm->hlBorder = frame_obj->hlBorder;
 
             SaveMenuItem(f_itm, frame_obj);
         }
@@ -397,6 +408,11 @@ void SaveMenu(Menu mn)
     }
 }
 
+void SaveMenu(Menu mn)
+{
+    SaveMenu(mn, mn);
+}
+
 // Преобразования MenuItem <-> MenuRegion 
 ///////////////////////////////////////////////////////////////////////
 
