@@ -26,7 +26,7 @@
 
 #include <mlib/function.h>
 
-void SetPercent(Gtk::ProgressBar& bar, double percent);
+void SetPercent(Gtk::ProgressBar& bar, double percent, const std::string& info = std::string());
 
 // "прокрутить" очередь сообщений
 void IteratePendingEvents();
@@ -86,6 +86,7 @@ void SetForRadioToggle(RadioItem& itm, const ActionFunctor& fnr)
     itm.signal_toggled().connect(RadioToggleCaller<RadioItem>(itm, fnr));
 }
 
+Gtk::Adjustment& CreateAdj(double val, double max, double min = 1.0, int step = 1);
 void ConfigureSpin(Gtk::SpinButton& btn, double val, double max, double min = 1.0, int step = 1);
 
 RGBA::Pixel GetColor(const Gtk::ColorButton& btn);
@@ -99,5 +100,10 @@ Gtk::VBox& PackParaBox(Gtk::VBox& vbox, const char* name);
 
 bool SetFilename(Gtk::FileChooser& fc, const std::string& fpath);
 
+Gtk::HBox& PackCompositeWdg(Gtk::Widget& wdg);
+
+void PackCompositeWdgButton(Gtk::HBox& hbox, const Gtk::BuiltinStockID& stock_id,
+                            const ActionFunctor& fnr, const char* tooltip = "");
+
 #endif // #ifndef __MGUI_SDK_WIDGET_H__
 
