@@ -23,6 +23,19 @@
 #include "tech.h"
 #include "format.h"
 
+// :TRICKY: со временем может измениться (в бусте), но создавать
+// свою хлопотнее пока, см. boost/detail/utf8_codecvt_facet.hpp
+#include <boost/filesystem/detail/utf8_codecvt_facet.hpp>
+// в 1.51 v2 удалена полностью (svn diff -r 77555:HEAD -- boost/version.hpp | less)
+#if BOOST_MINOR_VERSION >= 51
+#define BOOST_FS_3 boost::filesystem
+#include <boost/filesystem/path_traits.hpp> // boost::filesystem::convert()
+#else
+#define BOOST_FS_3 boost::filesystem3
+#include <boost/filesystem/v3/path_traits.hpp>
+#endif 
+
+
 #include <string.h> // strstr()
 
 namespace boost { namespace filesystem {
@@ -38,6 +51,27 @@ std::string operator / (const path& f, to_string_enum /*to_str*/)
     return f.string();
 }
 
+#ifdef BFS_VERSION_3
+
+std::string name_str(const path& pth)
+{
+    return pth.filename().string();
+}
+
+#else
+
+std::string name_str(const path& pth)
+{
+    return pth.leaf();
+}
+
+#endif // BFS_VERSION_3
+
+std::string name_str(const std::string& pth)
+{
+    return name_str(path(pth));
+}
+
 } } // namepspace filesystem, boost
 
 const char* FindExtDot(const char* name)
@@ -45,6 +79,30 @@ const char* FindExtDot(const char* name)
     return strrchr(name, '.');
 }
 
+#ifdef BFS_VERSION_3
+
+std::string get_basename(const fs::path& pth)
+{
+    return pth.stem().string();
+}
+
+std::string get_extension(const fs::path& pth)
+{
+    // path("/foo/bar.txt").extension() => ".txt"
+    // path("foo.bar.baz.tar").extension() => ".tar"
+    // а нам нужно без точки
+    std::string ext = pth.extension().string();
+    if( !ext.empty() )
+    {
+        const char* ext_c = ext.c_str();
+        ASSERT_RTL( ext_c[0] == '.' );
+        std::string(ext_c + 1).swap(ext);
+    }
+    return ext;
+}
+
+#else
+
 std::string get_basename(const fs::path& pth)
 {
     std::string name_s = pth.leaf();
@@ -65,17 +123,39 @@ std::string get_extension(const fs::path& pth)
     return std::string();
 }
 
-// глобальная установка проверки имен файлов
+#endif // BFS_VERSION_3
+
 class tune_boost_filesystem
 {
     public:
     tune_boost_filesystem()
     {
-        // чтоб любые символы в именах файлов позволялись, для utf8
-        fs::path::default_name_check(fs::native);
+        // B.FS: отказались от проверок в ver>=2
+        //// глобальная установка проверки имен файлов
+        //// чтоб любые символы в именах файлов позволялись, для utf8
+        //fs::path::default_name_check(fs::native);
+
+#if defined(_WIN32) && defined(BFS_VERSION_3)
+        // внутри используем utf-8 => меняем конвертор
+        std::locale utf8_loc(std::locale(), new fs::detail::utf8_codecvt_facet);
+        fs::path::imbue(utf8_loc);
+#endif
     }
 } tune_boost_filesystem_obj;
 
+std::wstring Utf8ToUcs16(const char* utf8_str)
+{
+    std::wstring res;
+#ifdef _WIN32
+    // можно напрямую использовать utf8_codecvt_facet, но так проще
+    // (будет работать при fs::path::imbue(utf8_loc);)
+    BOOST_FS_3::path_traits::convert(utf8_str, 0, res, fs::path::codecvt());
+#else
+    ASSERT(0);
+#endif
+    return res;
+}
+
 namespace Project
 {
 
